@@ -143,8 +143,8 @@ from typing import (
     TYPE_CHECKING,
     Any,
     AsyncContextManager,
+    Awaitable,
     Callable,
-    Coroutine,
     Mapping,
     MutableMapping,
     NoReturn,
@@ -167,7 +167,6 @@ from pymongo.errors import (
     WTimeoutError,
 )
 from pymongo.helpers_shared import _RETRYABLE_ERROR_CODES
-from pymongo.operations import _Op
 from pymongo.read_concern import ReadConcern
 from pymongo.read_preferences import ReadPreference, _ServerMode
 from pymongo.server_type import SERVER_TYPE
@@ -396,7 +395,7 @@ class _TxnState:
 class _Transaction:
     """Internal class to hold transaction information in a AsyncClientSession."""
 
-    def __init__(self, opts: Optional[TransactionOptions], client: AsyncMongoClient):
+    def __init__(self, opts: Optional[TransactionOptions], client: AsyncMongoClient[Any]):
         self.opts = opts
         self.state = _TxnState.NONE
         self.sharded = False
@@ -459,7 +458,7 @@ def _max_time_expired_error(exc: PyMongoError) -> bool:
 
 # From the transactions spec, all the retryable writes errors plus
 # WriteConcernTimeout.
-_UNKNOWN_COMMIT_ERROR_CODES: frozenset = _RETRYABLE_ERROR_CODES | frozenset(
+_UNKNOWN_COMMIT_ERROR_CODES: frozenset = _RETRYABLE_ERROR_CODES | frozenset(  # type: ignore[type-arg]
     [
         64,  # WriteConcernTimeout
         50,  # MaxTimeMSExpired
@@ -499,13 +498,13 @@ class AsyncClientSession:
 
     def __init__(
         self,
-        client: AsyncMongoClient,
+        client: AsyncMongoClient[Any],
         server_session: Any,
         options: SessionOptions,
         implicit: bool,
     ) -> None:
         # An AsyncMongoClient, a _ServerSession, a SessionOptions, and a set.
-        self._client: AsyncMongoClient = client
+        self._client: AsyncMongoClient[Any] = client
         self._server_session = server_session
         self._options = options
         self._cluster_time: Optional[Mapping[str, Any]] = None
@@ -551,7 +550,7 @@ class AsyncClientSession:
         await self._end_session(lock=True)
 
     @property
-    def client(self) -> AsyncMongoClient:
+    def client(self) -> AsyncMongoClient[Any]:
         """The :class:`~pymongo.asynchronous.mongo_client.AsyncMongoClient` this session was
         created from.
         """
@@ -601,7 +600,7 @@ class AsyncClientSession:
 
     async def with_transaction(
         self,
-        callback: Callable[[AsyncClientSession], Coroutine[Any, Any, _T]],
+        callback: Callable[[AsyncClientSession], Awaitable[_T]],
         read_concern: Optional[ReadConcern] = None,
         write_concern: Optional[WriteConcern] = None,
         read_preference: Optional[_ServerMode] = None,
@@ -751,7 +750,7 @@ class AsyncClientSession:
         write_concern: Optional[WriteConcern] = None,
         read_preference: Optional[_ServerMode] = None,
         max_commit_time_ms: Optional[int] = None,
-    ) -> AsyncContextManager:
+    ) -> AsyncContextManager[Any]:
         """Start a multi-statement transaction.
 
         Takes the same arguments as :class:`TransactionOptions`.
@@ -868,7 +867,7 @@ class AsyncClientSession:
             return await self._finish_transaction(conn, command_name)
 
         return await self._client._retry_internal(
-            func, self, None, retryable=True, operation=_Op.ABORT
+            func, self, None, retryable=True, operation=command_name
         )
 
     async def _finish_transaction(self, conn: AsyncConnection, command_name: str) -> dict[str, Any]:
@@ -1123,7 +1122,7 @@ class _ServerSession:
         self._transaction_id += 1
 
 
-class _ServerSessionPool(collections.deque):
+class _ServerSessionPool(collections.deque):  # type: ignore[type-arg]
     """Pool of _ServerSession objects.
 
     This class is thread-safe.
