@@ -322,7 +322,7 @@ class TopologyDescription:
         if address:
             # Ignore selectors when explicit address is requested.
             description = self.server_descriptions().get(address)
-            return [description] if description else []
+            return [description] if description and description.is_server_type_known else []
 
         # Primary selection fast path.
         if self.topology_type == TOPOLOGY_TYPE.ReplicaSetWithPrimary and type(selector) is Primary:
@@ -569,8 +569,8 @@ def _update_rs_from_primary(
         return _check_has_primary(sds), replica_set_name, max_set_version, max_election_id
 
     if server_description.max_wire_version is None or server_description.max_wire_version < 17:
-        new_election_tuple: tuple = (server_description.set_version, server_description.election_id)
-        max_election_tuple: tuple = (max_set_version, max_election_id)
+        new_election_tuple: tuple = (server_description.set_version, server_description.election_id)  # type: ignore[type-arg]
+        max_election_tuple: tuple = (max_set_version, max_election_id)  # type: ignore[type-arg]
         if None not in new_election_tuple:
             if None not in max_election_tuple and new_election_tuple < max_election_tuple:
                 # Stale primary, set to type Unknown.
