@@ -33,6 +33,7 @@ import warnings
 from inspect import iscoroutinefunction
 
 from pymongo.asynchronous.uri_parser import parse_uri
+from pymongo.encryption_options import _HAVE_PYMONGOCRYPT
 from pymongo.errors import AutoReconnect
 
 try:
@@ -59,7 +60,8 @@ from pymongo.ssl_support import HAVE_SSL, _ssl  # type:ignore[attr-defined]
 
 sys.path[0:0] = [""]
 
-from test.helpers import (
+from test.asynchronous.helpers import client_knobs, global_knobs
+from test.helpers_shared import (
     COMPRESSORS,
     IS_SRV,
     MONGODB_API_VERSION,
@@ -67,10 +69,8 @@ from test.helpers import (
     TEST_LOADBALANCER,
     TLS_OPTIONS,
     SystemCertsPatcher,
-    client_knobs,
     db_pwd,
     db_user,
-    global_knobs,
     host,
     is_server_resolvable,
     port,
@@ -525,6 +525,19 @@ class AsyncClientContext:
             "Server version must be at most %s" % str(other_version),
         )
 
+    def require_libmongocrypt_min(self, *ver):
+        other_version = Version(*ver)
+        if not _HAVE_PYMONGOCRYPT:
+            version = Version.from_string("0.0.0")
+        else:
+            from pymongocrypt import libmongocrypt_version
+
+            version = Version.from_string(libmongocrypt_version())
+        return self._require(
+            lambda: version >= other_version,
+            "Libmongocrypt version must be at least %s" % str(other_version),
+        )
+
     def require_auth(self, func):
         """Run a test only if the server is running with auth enabled."""
         return self._require(
