@@ -68,26 +68,26 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         started = self.listener.started_events[0]
         succeeded = self.listener.succeeded_events[0]
         self.assertEqual(0, len(self.listener.failed_events))
-        self.assertTrue(isinstance(succeeded, monitoring.CommandSucceededEvent))
-        self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
+        self.assertIsInstance(succeeded, monitoring.CommandSucceededEvent)
+        self.assertIsInstance(started, monitoring.CommandStartedEvent)
         self.assertEqualCommand(SON([("ping", 1)]), started.command)
         self.assertEqual("ping", started.command_name)
         self.assertEqual(await self.client.address, started.connection_id)
         self.assertEqual("pymongo_test", started.database_name)
-        self.assertTrue(isinstance(started.request_id, int))
+        self.assertIsInstance(started.request_id, int)
 
     async def test_succeeded_simple(self):
         await self.client.pymongo_test.command("ping")
         started = self.listener.started_events[0]
         succeeded = self.listener.succeeded_events[0]
         self.assertEqual(0, len(self.listener.failed_events))
-        self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
-        self.assertTrue(isinstance(succeeded, monitoring.CommandSucceededEvent))
+        self.assertIsInstance(started, monitoring.CommandStartedEvent)
+        self.assertIsInstance(succeeded, monitoring.CommandSucceededEvent)
         self.assertEqual("ping", succeeded.command_name)
         self.assertEqual(await self.client.address, succeeded.connection_id)
         self.assertEqual(1, succeeded.reply.get("ok"))
-        self.assertTrue(isinstance(succeeded.request_id, int))
-        self.assertTrue(isinstance(succeeded.duration_micros, int))
+        self.assertIsInstance(succeeded.request_id, int)
+        self.assertIsInstance(succeeded.duration_micros, int)
 
     async def test_failed_simple(self):
         try:
@@ -97,21 +97,21 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         started = self.listener.started_events[0]
         failed = self.listener.failed_events[0]
         self.assertEqual(0, len(self.listener.succeeded_events))
-        self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
-        self.assertTrue(isinstance(failed, monitoring.CommandFailedEvent))
+        self.assertIsInstance(started, monitoring.CommandStartedEvent)
+        self.assertIsInstance(failed, monitoring.CommandFailedEvent)
         self.assertEqual("oops!", failed.command_name)
         self.assertEqual(await self.client.address, failed.connection_id)
         self.assertEqual(0, failed.failure.get("ok"))
-        self.assertTrue(isinstance(failed.request_id, int))
-        self.assertTrue(isinstance(failed.duration_micros, int))
+        self.assertIsInstance(failed.request_id, int)
+        self.assertIsInstance(failed.duration_micros, int)
 
     async def test_find_one(self):
         await self.client.pymongo_test.test.find_one()
         started = self.listener.started_events[0]
         succeeded = self.listener.succeeded_events[0]
         self.assertEqual(0, len(self.listener.failed_events))
-        self.assertTrue(isinstance(succeeded, monitoring.CommandSucceededEvent))
-        self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
+        self.assertIsInstance(succeeded, monitoring.CommandSucceededEvent)
+        self.assertIsInstance(started, monitoring.CommandStartedEvent)
         self.assertEqualCommand(
             SON([("find", "test"), ("filter", {}), ("limit", 1), ("singleBatch", True)]),
             started.command,
@@ -119,7 +119,7 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         self.assertEqual("find", started.command_name)
         self.assertEqual(await self.client.address, started.connection_id)
         self.assertEqual("pymongo_test", started.database_name)
-        self.assertTrue(isinstance(started.request_id, int))
+        self.assertIsInstance(started.request_id, int)
 
     async def test_find_and_get_more(self):
         await self.client.pymongo_test.test.drop()
@@ -132,7 +132,7 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         started = self.listener.started_events[0]
         succeeded = self.listener.succeeded_events[0]
         self.assertEqual(0, len(self.listener.failed_events))
-        self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
+        self.assertIsInstance(started, monitoring.CommandStartedEvent)
         self.assertEqualCommand(
             SON(
                 [("find", "test"), ("filter", {}), ("projection", {"_id": False}), ("batchSize", 4)]
@@ -142,11 +142,11 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         self.assertEqual("find", started.command_name)
         self.assertEqual(await self.client.address, started.connection_id)
         self.assertEqual("pymongo_test", started.database_name)
-        self.assertTrue(isinstance(started.request_id, int))
-        self.assertTrue(isinstance(succeeded, monitoring.CommandSucceededEvent))
-        self.assertTrue(isinstance(succeeded.duration_micros, int))
+        self.assertIsInstance(started.request_id, int)
+        self.assertIsInstance(succeeded, monitoring.CommandSucceededEvent)
+        self.assertIsInstance(succeeded.duration_micros, int)
         self.assertEqual("find", succeeded.command_name)
-        self.assertTrue(isinstance(succeeded.request_id, int))
+        self.assertIsInstance(succeeded.request_id, int)
         self.assertEqual(cursor.address, succeeded.connection_id)
         csr = succeeded.reply["cursor"]
         self.assertEqual(csr["id"], cursor_id)
@@ -161,7 +161,7 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
             started = self.listener.started_events[0]
             succeeded = self.listener.succeeded_events[0]
             self.assertEqual(0, len(self.listener.failed_events))
-            self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
+            self.assertIsInstance(started, monitoring.CommandStartedEvent)
             self.assertEqualCommand(
                 SON([("getMore", cursor_id), ("collection", "test"), ("batchSize", 4)]),
                 started.command,
@@ -169,11 +169,11 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
             self.assertEqual("getMore", started.command_name)
             self.assertEqual(await self.client.address, started.connection_id)
             self.assertEqual("pymongo_test", started.database_name)
-            self.assertTrue(isinstance(started.request_id, int))
-            self.assertTrue(isinstance(succeeded, monitoring.CommandSucceededEvent))
-            self.assertTrue(isinstance(succeeded.duration_micros, int))
+            self.assertIsInstance(started.request_id, int)
+            self.assertIsInstance(succeeded, monitoring.CommandSucceededEvent)
+            self.assertIsInstance(succeeded.duration_micros, int)
             self.assertEqual("getMore", succeeded.command_name)
-            self.assertTrue(isinstance(succeeded.request_id, int))
+            self.assertIsInstance(succeeded.request_id, int)
             self.assertEqual(cursor.address, succeeded.connection_id)
             csr = succeeded.reply["cursor"]
             self.assertEqual(csr["id"], cursor_id)
@@ -196,16 +196,16 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         started = self.listener.started_events[0]
         succeeded = self.listener.succeeded_events[0]
         self.assertEqual(0, len(self.listener.failed_events))
-        self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
+        self.assertIsInstance(started, monitoring.CommandStartedEvent)
         self.assertEqualCommand(cmd, started.command)
         self.assertEqual("explain", started.command_name)
         self.assertEqual(await self.client.address, started.connection_id)
         self.assertEqual("pymongo_test", started.database_name)
-        self.assertTrue(isinstance(started.request_id, int))
-        self.assertTrue(isinstance(succeeded, monitoring.CommandSucceededEvent))
-        self.assertTrue(isinstance(succeeded.duration_micros, int))
+        self.assertIsInstance(started.request_id, int)
+        self.assertIsInstance(succeeded, monitoring.CommandSucceededEvent)
+        self.assertIsInstance(succeeded.duration_micros, int)
         self.assertEqual("explain", succeeded.command_name)
-        self.assertTrue(isinstance(succeeded.request_id, int))
+        self.assertIsInstance(succeeded.request_id, int)
         self.assertEqual(await self.client.address, succeeded.connection_id)
         self.assertEqual(res, succeeded.reply)
 
@@ -227,16 +227,16 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
             started = self.listener.started_events[0]
             succeeded = self.listener.succeeded_events[0]
             self.assertEqual(0, len(self.listener.failed_events))
-            self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
+            self.assertIsInstance(started, monitoring.CommandStartedEvent)
             self.assertEqualCommand(expected_cmd, started.command)
             self.assertEqual("find", started.command_name)
             self.assertEqual(await self.client.address, started.connection_id)
             self.assertEqual("pymongo_test", started.database_name)
-            self.assertTrue(isinstance(started.request_id, int))
-            self.assertTrue(isinstance(succeeded, monitoring.CommandSucceededEvent))
-            self.assertTrue(isinstance(succeeded.duration_micros, int))
+            self.assertIsInstance(started.request_id, int)
+            self.assertIsInstance(succeeded, monitoring.CommandSucceededEvent)
+            self.assertIsInstance(succeeded.duration_micros, int)
             self.assertEqual("find", succeeded.command_name)
-            self.assertTrue(isinstance(succeeded.request_id, int))
+            self.assertIsInstance(succeeded.request_id, int)
             self.assertEqual(await self.client.address, succeeded.connection_id)
         finally:
             # Exhaust the cursor to avoid kill cursors.
@@ -308,7 +308,7 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         started = self.listener.started_events[0]
         succeeded = self.listener.succeeded_events[0]
         self.assertEqual(0, len(self.listener.failed_events))
-        self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
+        self.assertIsInstance(started, monitoring.CommandStartedEvent)
         self.assertEqualCommand(
             SON(
                 [
@@ -322,11 +322,11 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         self.assertEqual("aggregate", started.command_name)
         self.assertEqual(await self.client.address, started.connection_id)
         self.assertEqual("pymongo_test", started.database_name)
-        self.assertTrue(isinstance(started.request_id, int))
-        self.assertTrue(isinstance(succeeded, monitoring.CommandSucceededEvent))
-        self.assertTrue(isinstance(succeeded.duration_micros, int))
+        self.assertIsInstance(started.request_id, int)
+        self.assertIsInstance(succeeded, monitoring.CommandSucceededEvent)
+        self.assertIsInstance(succeeded.duration_micros, int)
         self.assertEqual("aggregate", succeeded.command_name)
-        self.assertTrue(isinstance(succeeded.request_id, int))
+        self.assertIsInstance(succeeded.request_id, int)
         self.assertEqual(cursor.address, succeeded.connection_id)
         expected_cursor = {
             "id": cursor_id,
@@ -341,7 +341,7 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
             started = self.listener.started_events[0]
             succeeded = self.listener.succeeded_events[0]
             self.assertEqual(0, len(self.listener.failed_events))
-            self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
+            self.assertIsInstance(started, monitoring.CommandStartedEvent)
             self.assertEqualCommand(
                 SON([("getMore", cursor_id), ("collection", "test"), ("batchSize", 4)]),
                 started.command,
@@ -349,11 +349,11 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
             self.assertEqual("getMore", started.command_name)
             self.assertEqual(await self.client.address, started.connection_id)
             self.assertEqual("pymongo_test", started.database_name)
-            self.assertTrue(isinstance(started.request_id, int))
-            self.assertTrue(isinstance(succeeded, monitoring.CommandSucceededEvent))
-            self.assertTrue(isinstance(succeeded.duration_micros, int))
+            self.assertIsInstance(started.request_id, int)
+            self.assertIsInstance(succeeded, monitoring.CommandSucceededEvent)
+            self.assertIsInstance(succeeded.duration_micros, int)
             self.assertEqual("getMore", succeeded.command_name)
-            self.assertTrue(isinstance(succeeded.request_id, int))
+            self.assertIsInstance(succeeded.request_id, int)
             self.assertEqual(cursor.address, succeeded.connection_id)
             expected_result = {
                 "cursor": {
@@ -381,18 +381,18 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         started = self.listener.started_events[0]
         self.assertEqual(0, len(self.listener.succeeded_events))
         failed = self.listener.failed_events[0]
-        self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
+        self.assertIsInstance(started, monitoring.CommandStartedEvent)
         self.assertEqualCommand(
             SON([("getMore", cursor_id), ("collection", "test")]), started.command
         )
         self.assertEqual("getMore", started.command_name)
         self.assertEqual(await self.client.address, started.connection_id)
         self.assertEqual("pymongo_test", started.database_name)
-        self.assertTrue(isinstance(started.request_id, int))
-        self.assertTrue(isinstance(failed, monitoring.CommandFailedEvent))
-        self.assertTrue(isinstance(failed.duration_micros, int))
+        self.assertIsInstance(started.request_id, int)
+        self.assertIsInstance(failed, monitoring.CommandFailedEvent)
+        self.assertIsInstance(failed.duration_micros, int)
         self.assertEqual("getMore", failed.command_name)
-        self.assertTrue(isinstance(failed.request_id, int))
+        self.assertIsInstance(failed.request_id, int)
         self.assertEqual(cursor.address, failed.connection_id)
         self.assertEqual(0, failed.failure.get("ok"))
 
@@ -412,13 +412,13 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         started = self.listener.started_events[0]
         failed = self.listener.failed_events[0]
         self.assertEqual(0, len(self.listener.succeeded_events))
-        self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
-        self.assertTrue(isinstance(failed, monitoring.CommandFailedEvent))
+        self.assertIsInstance(started, monitoring.CommandStartedEvent)
+        self.assertIsInstance(failed, monitoring.CommandFailedEvent)
         self.assertEqual("findAndModify", failed.command_name)
         self.assertEqual(address, failed.connection_id)
         self.assertEqual(0, failed.failure.get("ok"))
-        self.assertTrue(isinstance(failed.request_id, int))
-        self.assertTrue(isinstance(failed.duration_micros, int))
+        self.assertIsInstance(failed.request_id, int)
+        self.assertIsInstance(failed.duration_micros, int)
         self.assertEqual(error, failed.failure)
 
     @async_client_context.require_no_mongos
@@ -434,7 +434,7 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         started = self.listener.started_events[0]
         succeeded = self.listener.succeeded_events[0]
         self.assertEqual(0, len(self.listener.failed_events))
-        self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
+        self.assertIsInstance(started, monitoring.CommandStartedEvent)
         self.assertEqualCommand(
             SON(
                 [("find", "test"), ("filter", {}), ("projection", {"_id": False}), ("batchSize", 5)]
@@ -444,11 +444,11 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         self.assertEqual("find", started.command_name)
         self.assertEqual(cursor.address, started.connection_id)
         self.assertEqual("pymongo_test", started.database_name)
-        self.assertTrue(isinstance(started.request_id, int))
-        self.assertTrue(isinstance(succeeded, monitoring.CommandSucceededEvent))
-        self.assertTrue(isinstance(succeeded.duration_micros, int))
+        self.assertIsInstance(started.request_id, int)
+        self.assertIsInstance(succeeded, monitoring.CommandSucceededEvent)
+        self.assertIsInstance(succeeded.duration_micros, int)
         self.assertEqual("find", succeeded.command_name)
-        self.assertTrue(isinstance(succeeded.request_id, int))
+        self.assertIsInstance(succeeded.request_id, int)
         self.assertEqual(cursor.address, succeeded.connection_id)
         expected_result = {
             "cursor": {
@@ -464,7 +464,7 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         tuple(await cursor.to_list())
         self.assertEqual(0, len(self.listener.failed_events))
         for event in self.listener.started_events:
-            self.assertTrue(isinstance(event, monitoring.CommandStartedEvent))
+            self.assertIsInstance(event, monitoring.CommandStartedEvent)
             self.assertEqualCommand(
                 SON([("getMore", cursor_id), ("collection", "test"), ("batchSize", 5)]),
                 event.command,
@@ -472,12 +472,12 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
             self.assertEqual("getMore", event.command_name)
             self.assertEqual(cursor.address, event.connection_id)
             self.assertEqual("pymongo_test", event.database_name)
-            self.assertTrue(isinstance(event.request_id, int))
+            self.assertIsInstance(event.request_id, int)
         for event in self.listener.succeeded_events:
-            self.assertTrue(isinstance(event, monitoring.CommandSucceededEvent))
-            self.assertTrue(isinstance(event.duration_micros, int))
+            self.assertIsInstance(event, monitoring.CommandSucceededEvent)
+            self.assertIsInstance(event.duration_micros, int)
             self.assertEqual("getMore", event.command_name)
-            self.assertTrue(isinstance(event.request_id, int))
+            self.assertIsInstance(event.request_id, int)
             self.assertEqual(cursor.address, event.connection_id)
         # Last getMore receives a response with cursor id 0.
         self.assertEqual(0, self.listener.succeeded_events[-1].reply["cursor"]["id"])
@@ -495,7 +495,7 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
             started = self.listener.started_events[0]
             succeeded = self.listener.succeeded_events[0]
             self.assertEqual(0, len(self.listener.failed_events))
-            self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
+            self.assertIsInstance(started, monitoring.CommandStartedEvent)
             # There could be more than one cursor_id here depending on
             # when the thread last ran.
             self.assertIn(cursor_id, started.command["cursors"])
@@ -503,18 +503,17 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
             self.assertIs(type(started.connection_id), tuple)
             self.assertEqual(cursor.address, started.connection_id)
             self.assertEqual("pymongo_test", started.database_name)
-            self.assertTrue(isinstance(started.request_id, int))
-            self.assertTrue(isinstance(succeeded, monitoring.CommandSucceededEvent))
-            self.assertTrue(isinstance(succeeded.duration_micros, int))
+            self.assertIsInstance(started.request_id, int)
+            self.assertIsInstance(succeeded, monitoring.CommandSucceededEvent)
+            self.assertIsInstance(succeeded.duration_micros, int)
             self.assertEqual("killCursors", succeeded.command_name)
-            self.assertTrue(isinstance(succeeded.request_id, int))
+            self.assertIsInstance(succeeded.request_id, int)
             self.assertIs(type(succeeded.connection_id), tuple)
             self.assertEqual(cursor.address, succeeded.connection_id)
             # There could be more than one cursor_id here depending on
             # when the thread last ran.
-            self.assertTrue(
-                cursor_id in succeeded.reply["cursorsUnknown"]
-                or cursor_id in succeeded.reply["cursorsKilled"]
+            self.assertIn(
+                cursor_id, succeeded.reply["cursorsUnknown"] + succeeded.reply["cursorsKilled"]
             )
 
     async def test_non_bulk_writes(self):
@@ -1066,7 +1065,7 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         self.assertEqual(2, len(errors))
         fields = {"index", "code", "errmsg"}
         for error in errors:
-            self.assertTrue(fields.issubset(set(error)))
+            self.assertLessEqual(fields, set(error))
 
     async def test_first_batch_helper(self):
         # Regardless of server version and use of helpers._first_batch
@@ -1088,8 +1087,8 @@ class AsyncTestCommandMonitoring(AsyncIntegrationTest):
         self.assertEqual(started.command_name, succeeded.command_name)
         self.assertEqual(started.request_id, succeeded.request_id)
         self.assertEqual(started.connection_id, succeeded.connection_id)
-        self.assertTrue("cursor" in succeeded.reply)
-        self.assertTrue("ok" in succeeded.reply)
+        self.assertIn("cursor", succeeded.reply)
+        self.assertIn("ok", succeeded.reply)
 
         self.listener.reset()
 
@@ -1157,13 +1156,13 @@ class AsyncTestGlobalListener(AsyncIntegrationTest):
         started = self.listener.started_events[0]
         succeeded = self.listener.succeeded_events[0]
         self.assertEqual(0, len(self.listener.failed_events))
-        self.assertTrue(isinstance(succeeded, monitoring.CommandSucceededEvent))
-        self.assertTrue(isinstance(started, monitoring.CommandStartedEvent))
+        self.assertIsInstance(succeeded, monitoring.CommandSucceededEvent)
+        self.assertIsInstance(started, monitoring.CommandStartedEvent)
         self.assertEqualCommand(SON([("ping", 1)]), started.command)
         self.assertEqual("ping", started.command_name)
         self.assertEqual(await self.client.address, started.connection_id)
         self.assertEqual("pymongo_test", started.database_name)
-        self.assertTrue(isinstance(started.request_id, int))
+        self.assertIsInstance(started.request_id, int)
 
 
 class AsyncTestEventClasses(unittest.IsolatedAsyncioTestCase):
